@@ -680,32 +680,6 @@ impl<F: FnMut(Request<()>) -> InterceptedRequestResult> BigTable<F> {
         deserialize_protobuf_or_bincode_cell_data(&row_data, table, key)
     }
 
-    #[allow(clippy::needless_lifetimes)]
-    pub async fn get_protobuf_or_bincode_cells<'a, B, P>(
-        &mut self,
-        table: &'a str,
-        row_keys: impl IntoIterator<Item = RowKey>,
-    ) -> Result<impl Iterator<Item = (RowKey, CellData<B, P>)> + 'a>
-    where
-        B: serde::de::DeserializeOwned,
-        P: prost::Message + Default,
-    {
-        Ok(self
-            .get_multi_row_data(
-                table,
-                row_keys.into_iter().collect::<Vec<RowKey>>().as_slice(),
-            )
-            .await?
-            .into_iter()
-            .map(|(key, row_data)| {
-                let key_str = key.to_string();
-                (
-                    key,
-                    deserialize_protobuf_or_bincode_cell_data(&row_data, table, key_str).unwrap(),
-                )
-            }))
-    }
-
     pub async fn put_bincode_cells<T>(
         &mut self,
         table: &str,
@@ -816,11 +790,14 @@ mod tests {
         super::*,
         crate::StoredConfirmedBlock,
         prost::Message,
-        solana_sdk::{hash::Hash, signature::Keypair, system_transaction},
+        solana_sdk::{
+            hash::Hash, message::v0::LoadedAddresses, signature::Keypair, system_transaction,
+            transaction::VersionedTransaction,
+        },
         solana_storage_proto::convert::generated,
         solana_transaction_status::{
-            ConfirmedBlock, ConfirmedBlockWithOptionalMetadata, TransactionStatusMeta,
-            TransactionWithMetadata,
+            ConfirmedBlock, TransactionStatusMeta, TransactionWithStatusMeta,
+            VersionedTransactionWithStatusMeta,
         },
         std::convert::TryInto,
     };
@@ -840,7 +817,7 @@ mod tests {
             previous_blockhash,
             blockhash,
             parent_slot,
-            transactions: transactions.into_iter().map(Into::into).collect(),
+            transactions: transactions.into_iter().map(|tx| tx.into()).collect(),
             rewards: rewards.into_iter().map(|r| r.into()).collect(),
             block_time: block_time.map(|timestamp| generated::UnixTimestamp { timestamp }),
             block_height: block_height.map(|block_height| generated::BlockHeight { block_height }),
@@ -852,8 +829,8 @@ mod tests {
         let from = Keypair::new();
         let recipient = solana_sdk::pubkey::new_rand();
         let transaction = system_transaction::transfer(&from, &recipient, 42, Hash::default());
-        let with_meta = TransactionWithMetadata {
-            transaction,
+        let with_meta = TransactionWithStatusMeta::Complete(VersionedTransactionWithStatusMeta {
+            transaction: VersionedTransaction::from(transaction),
             meta: TransactionStatusMeta {
                 status: Ok(()),
                 fee: 1,
@@ -864,8 +841,9 @@ mod tests {
                 pre_token_balances: Some(vec![]),
                 post_token_balances: Some(vec![]),
                 rewards: Some(vec![]),
+                loaded_addresses: LoadedAddresses::default(),
             },
-        };
+        });
         let expected_block = ConfirmedBlock {
             transactions: vec![with_meta],
             parent_slot: 1,
@@ -876,10 +854,7 @@ mod tests {
             block_height: Some(1),
         };
         let bincode_block = compress_best(
-            &bincode::serialize::<StoredConfirmedBlock>(
-                &ConfirmedBlockWithOptionalMetadata::from(expected_block.clone()).into(),
-            )
-            .unwrap(),
+            &bincode::serialize::<StoredConfirmedBlock>(&expected_block.clone().into()).unwrap(),
         )
         .unwrap();
 
@@ -898,10 +873,7 @@ mod tests {
         )
         .unwrap();
         if let CellData::Protobuf(protobuf_block) = deserialized {
-            assert_eq!(
-                ConfirmedBlockWithOptionalMetadata::from(expected_block.clone()),
-                protobuf_block.try_into().unwrap(),
-            );
+            assert_eq!(expected_block, protobuf_block.try_into().unwrap());
         } else {
             panic!("deserialization should produce CellData::Protobuf");
         }
@@ -917,18 +889,18 @@ mod tests {
         .unwrap();
         if let CellData::Bincode(bincode_block) = deserialized {
             let mut block = expected_block;
+            if let TransactionWithStatusMeta::Complete(VersionedTransactionWithStatusMeta {
+                meta,
+                ..
+            }) = &mut block.transactions[0]
             {
-                let mut meta = &mut block.transactions[0].meta;
                 meta.inner_instructions = None; // Legacy bincode implementation does not support inner_instructions
                 meta.log_messages = None; // Legacy bincode implementation does not support log_messages
                 meta.pre_token_balances = None; // Legacy bincode implementation does not support token balances
                 meta.post_token_balances = None; // Legacy bincode implementation does not support token balances
                 meta.rewards = None; // Legacy bincode implementation does not support rewards
             }
-            assert_eq!(
-                ConfirmedBlockWithOptionalMetadata::from(block),
-                ConfirmedBlockWithOptionalMetadata::from(bincode_block)
-            );
+            assert_eq!(block, bincode_block.into());
         } else {
             panic!("deserialization should produce CellData::Bincode");
         }
